==> higher-order-fetch-0.0.4.tgz: package/hofs/onErrorRetry.js <==
import { defer, from, throwError, of } from 'rxjs';
import { retryWhen, mergeMap, delay } from 'rxjs/operators';

var defaultOptions = {
  maxRetry: 3,
  maxDelay: 500
};

var get = function get(obj, field, defaultValue) {
  return (obj || {})[field] || defaultValue;
};
/**
 * NOTE: This requires `rxjs` as peer dependency.
 * Creat a fetch which retries when:
 * + GET with 5XX error
 * + Network error
 * @param {*} fetch
 */


var onErrorRetry = function onErrorRetry(options) {
  return function (fetch) {
    return function (input) {
      var init = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var maxRetry = get(options, "maxRetry", defaultOptions.maxRetry);
      var maxDelay = get(options, "maxDelay", defaultOptions.maxDelay);

      if (!init.method || init.method.toUpperCase() === "GET") {
        var count = 0;
        return defer(function () {
          return from(fetch(input, init).then(function (resp) {
            if ((resp.status + "").startsWith("5")) throw resp;
            return resp;
          }));
        }).pipe(retryWhen(function (errors) {
          return errors.pipe(mergeMap(function (error) {
            if (++count >= maxRetry) {
              return throwError(error);
            } else {
              return of(error).pipe(delay(maxDelay));
            }
          }));
        })).toPromise().then(function (resp) {
          return resp;
        }, function (resp) {
          if (resp.status === 500) return resp;
          throw resp;
        });
      }

      return fetch(input, init);
    };
  };
};

export { onErrorRetry };

==> higher-order-fetch-0.0.8.tgz: package/hofs/onErrorRetry.js <==
import { defer, from, throwError, of } from 'rxjs';
import { retryWhen, mergeMap, delay } from 'rxjs/operators';

var defaultOptions = {
  maxRetry: 3,
  delayMs: 500
};

var get = function get(obj, field, defaultValue) {
  return (obj || {})[field] || defaultValue;
};
/**
 *
 * Creat a fetch which retries when:
 * + GET with 5XX error
 * + Network error
 * @requires `rxjs`
 * @example
 * import {onErrorRetry} from 'higher-order-fetch/hofs/onErrorRetry'
 *
 * const fetch = onErrorRetry({
 *  maxRetry: 5,
 *  delayMs: 3000
 * })(window.fetch)
 *
 * fetch('http://example.com')// if request error, will retry maximum 5 times before resolve
 * .then(response => {
 *  // `response` is the last response after all retries or success.
 * })
 * @param {{maxRetry: number, delayMs: number}} [options]
 * @returns {function} a fetch-like function
 */


var onErrorRetry = function onErrorRetry(options) {
  return function (fetch) {
    return function (input) {
      var init = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var maxRetry = get(options, "maxRetry", defaultOptions.maxRetry);
      var delayMs = get(options, "delayMs", defaultOptions.delayMs);

      if (!init.method || init.method.toUpperCase() === "GET") {
        var count = 0;
        return defer(function () {
          return from(fetch(input, init).then(function (resp) {
            if ((resp.status + "").startsWith("5")) throw resp;
            return resp;
          }));
        }).pipe(retryWhen(function (errors) {
          return errors.pipe(mergeMap(function (error) {
            if (++count >= maxRetry) {
              return throwError(error);
            } else {
              return of(error).pipe(delay(delayMs));
            }
          }));
        })).toPromise().then(function (resp) {
          return resp;
        }, function (resp) {
          if (resp.status === 500) return resp;
          throw resp;
        });
      }

      return fetch(input, init);
    };
  };
};

export { onErrorRetry };
